/* XPM */
static char *mininf[] = {
  "19 19 4 1",
  "+ c none",
  "# c #183c59",
  "a c #ffffff",
  "b c #0000ff",
  "+++++++#####+++++++",
  "+++++##aaaaa##+++++",
  "++++#aabbbbbaa##+++",
  "+++#abbbaaabbbaa+++",
  "++#abbbaaaaabbb#a++",
  "+#abbbbbaaabbbbb#a+",
  "+#abbbbbbbbbbbbb#a+",
  "#abbbbaaaaabbbbbb#a",
  "#abbbbbbaaabbbbbb#a",
  "#abbbbbbaaabbbbbb#a",
  "#abbbbbbaaabbbbbb#a",
  "#abbbbbbaaabbbbbb#a",
  "+#abbbbbaaabbbbb#a+",
  "+#abbbbbaaabbbbb#a+",
  "++#abbaaaaaaabb#a++",
  "+++a#bbbbbbbbb#a+++",
  "++++a##bbbbb##a++++",
  "+++++aa#####aa+++++",
  "+++++++aaaaa+++++++"
};
